@@ -14,3 +14,8 @@ __all__ = (
     'IntegerField', 'IPAddressField', 'GenericIPAddressField',
     'NullBooleanField', 'TextField', 'TimeField', 'URLField'
 )
+
+
+import warnings
+
+warnings.warn("The package was merged into django-viewflow. Please consider to switch to django-viewflow>=2.0.0b1")
\ No newline at end of file
